# coding: utf-8

"""
    NIUM Platform

    NIUM Platform

    Contact: experience@nium.com
    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr, validator

class ClientPrefundResponseDTO(BaseModel):
    """
    ClientPrefundResponseDTO
    """
    amount: Optional[Union[StrictFloat, StrictInt]] = Field(None, description="This field contains the amount transferred to account.")
    message: Optional[StrictStr] = Field(None, description="This field will return a success message if the prefund request added successfully")
    status: Optional[StrictStr] = Field(None, description="This field contains the status.")
    system_reference_number: Optional[StrictStr] = Field(None, alias="systemReferenceNumber", description="This field contains the transaction reference number or identifier generated by card issuance platform for the client prefund request.")
    unique_payer_id: Optional[StrictStr] = Field(None, alias="uniquePayerId", description="This field contains the unique email ID provided to the customer in addition to uniquePaymentId for supported regions and configuration, or else it will be null, for example, abc12_ca@nium.com.")
    unique_payment_id: Optional[StrictStr] = Field(None, alias="uniquePaymentId", description="This field contains the virtual account number per currency provided to customers for supported regions and configuration, for example, IBAN in EU, virtual account number from Moonova in AU, or else, it will be null.")
    __properties = ["amount", "message", "status", "systemReferenceNumber", "uniquePayerId", "uniquePaymentId"]

    @validator('status')
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('Pending', 'Approved', 'Rejected'):
            raise ValueError("must be one of enum values ('Pending', 'Approved', 'Rejected')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ClientPrefundResponseDTO:
        """Create an instance of ClientPrefundResponseDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ClientPrefundResponseDTO:
        """Create an instance of ClientPrefundResponseDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ClientPrefundResponseDTO.parse_obj(obj)

        _obj = ClientPrefundResponseDTO.parse_obj({
            "amount": obj.get("amount"),
            "message": obj.get("message"),
            "status": obj.get("status"),
            "system_reference_number": obj.get("systemReferenceNumber"),
            "unique_payer_id": obj.get("uniquePayerId"),
            "unique_payment_id": obj.get("uniquePaymentId")
        })
        return _obj


